@@ -3,25 +3,22 @@ import asyncio
 import contextlib
 import inspect
 import socket
-import sys
 from concurrent.futures import ProcessPoolExecutor
 
 import pytest
 from _pytest.python import transfer_markers
 
+try:
+    from async_generator import isasyncgenfunction
+except ImportError:
+    from inspect import isasyncgenfunction
+
 
 def _is_coroutine(obj):
     """Check to see if an object is really an asyncio coroutine."""
     return asyncio.iscoroutinefunction(obj) or inspect.isgeneratorfunction(obj)
 
 
-if sys.version_info[:2] < (3, 6):
-    def isasyncgenfunction(_):
-        return False
-else:
-    from inspect import isasyncgenfunction
-
-
 def pytest_configure(config):
     """Inject documentation."""
     config.addinivalue_line("markers",
@@ -132,7 +129,12 @@ def pytest_fixture_setup(fixturedef, request):
             if kw not in request.keywords:
                 continue
             policy = asyncio.get_event_loop_policy()
-            old_loop = policy.get_event_loop()
+            try:
+                old_loop = policy.get_event_loop()
+            except RuntimeError as exc:
+                if 'no current event loop' not in str(exc):
+                    raise
+                old_loop = None
             policy.set_event_loop(loop)
             fixturedef.addfinalizer(lambda: policy.set_event_loop(old_loop))
 
